#
# spec file for package ghc-hakyll
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hakyll
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        4.12.4.0
Release:        lp150.2.12
Summary:        A static website compiler library
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-blaze-html-devel
BuildRequires:  ghc-blaze-markup-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-cryptohash-devel
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-file-embed-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-fsnotify-devel
BuildRequires:  ghc-http-conduit-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-lrucache-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-network-uri-devel
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-pandoc-citeproc-devel
BuildRequires:  ghc-pandoc-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-regex-tdfa-devel
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-tagsoup-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-locale-compat-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-wai-app-static-devel
BuildRequires:  ghc-wai-devel
BuildRequires:  ghc-warp-devel
BuildRequires:  ghc-yaml-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-quickcheck-devel
%endif

%description
Hakyll is a static website compiler library. It provides you with the tools to
create a simple or advanced static website using a Haskell DSL and formats such
as markdown or RST. You can find more information, including a tutorial, on the
website:

* <http://jaspervdj.be/hakyll>

If you seek assistance, there's:

* A google group: <http://groups.google.com/group/hakyll>

* An IRC channel, '#hakyll' on freenode

Additionally, there's the Haddock documentation in the different modules, meant
as a reference.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%{_bindir}/hakyll-init
%dir %{_datadir}/%{pkg_name}-%{version}
%dir %{_datadir}/%{pkg_name}-%{version}/example
%dir %{_datadir}/%{pkg_name}-%{version}/example/css
%dir %{_datadir}/%{pkg_name}-%{version}/example/images
%dir %{_datadir}/%{pkg_name}-%{version}/example/posts
%dir %{_datadir}/%{pkg_name}-%{version}/example/templates
%{_datadir}/%{pkg_name}-%{version}/example/about.rst
%{_datadir}/%{pkg_name}-%{version}/example/contact.markdown
%{_datadir}/%{pkg_name}-%{version}/example/css/default.css
%{_datadir}/%{pkg_name}-%{version}/example/images/haskell-logo.png
%{_datadir}/%{pkg_name}-%{version}/example/index.html
%{_datadir}/%{pkg_name}-%{version}/example/posts/2015-08-12-spqr.markdown
%{_datadir}/%{pkg_name}-%{version}/example/posts/2015-10-07-rosa-rosa-rosam.markdown
%{_datadir}/%{pkg_name}-%{version}/example/posts/2015-11-28-carpe-diem.markdown
%{_datadir}/%{pkg_name}-%{version}/example/posts/2015-12-07-tu-quoque.markdown
%{_datadir}/%{pkg_name}-%{version}/example/site.hs
%{_datadir}/%{pkg_name}-%{version}/example/templates/archive.html
%{_datadir}/%{pkg_name}-%{version}/example/templates/default.html
%{_datadir}/%{pkg_name}-%{version}/example/templates/post-list.html
%{_datadir}/%{pkg_name}-%{version}/example/templates/post.html

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%changelog
* Sun Sep 30 2018 psimons@suse.com
- Update hakyll to version 4.12.4.0.
  [#]# Hakyll 4.12.4.0 (2018-08-13)
  - Bump yaml to 0.10
  - Bump file-embed to 0.0.11
  - Bump QuickCheck to 2.12
  - Use makeRelativeToProject with embedFile for stack ghci (contribution by
    Michael Sloan)
* Tue Jul 10 2018 psimons@suse.com
- Add hakyll at version 4.12.3.0.
